==> icons-react-0.0.4.tgz: package/src/CloseTabs.tsx <==
// organize-imports-ignore
import React from "react";

export const CloseTabs = () => {
	return (
		<svg
			width="16"
			height="16"
			viewBox="0 0 16 16"
			fill="none"
			xmlns="http://www.w3.org/2000/svg"
		>
			<g clip-path="url(#clip0_1509_119)">
				<path
					fillRule="evenodd"
					clipRule="evenodd"
					d="M0 6H-2C-2.55228 6 -3 6.44772 -3 7V9C-3 9.55228 -2.55228 10 -2 10H0C0.552285 10 1 9.55228 1 9V7C1 6.44772 0.552285 6 0 6ZM-2 4C-3.65685 4 -5 5.34315 -5 7V9C-5 10.6569 -3.65685 12 -2 12H0C1.65685 12 3 10.6569 3 9V7C3 5.34315 1.65685 4 0 4H-2Z"
					fill="black"
					fill-opacity="0.5"
				/>
				<path
					fillRule="evenodd"
					clipRule="evenodd"
					d="M9 6H7C6.44772 6 6 6.44772 6 7V9C6 9.55228 6.44772 10 7 10H9C9.55228 10 10 9.55228 10 9V7C10 6.44772 9.55228 6 9 6ZM7 4C5.34315 4 4 5.34315 4 7V9C4 10.6569 5.34315 12 7 12H9C10.6569 12 12 10.6569 12 9V7C12 5.34315 10.6569 4 9 4H7Z"
					fill="black"
				/>
				<path
					fillRule="evenodd"
					clipRule="evenodd"
					d="M18 6H16C15.4477 6 15 6.44772 15 7V9C15 9.55228 15.4477 10 16 10H18C18.5523 10 19 9.55228 19 9V7C19 6.44772 18.5523 6 18 6ZM16 4C14.3431 4 13 5.34315 13 7V9C13 10.6569 14.3431 12 16 12H18C19.6569 12 21 10.6569 21 9V7C21 5.34315 19.6569 4 18 4H16Z"
					fill="black"
					fill-opacity="0.5"
				/>
			</g>
			<defs>
				<clipPath id="clip0_1509_119">
					<rect
						width="16"
						height="16"
						fill="white"
						transform="matrix(-1 0 0 1 16 0)"
					/>
				</clipPath>
			</defs>
		</svg>
	);
};

==> icons-react-0.0.9.tgz: package/src/CloseTabs.tsx <==
// organize-imports-ignore
import React from "react";

export const CloseTabs = (props: React.SVGProps<SVGSVGElement>) => {
	return (
		<svg
			width="16"
			height="16"
			viewBox="0 0 16 16"
			fill="none"
			xmlns="http://www.w3.org/2000/svg"
			{...props}
		>
			<g clipPath="url(#clip0_1509_119)">
				<path
					fillRule="evenodd"
					clipRule="evenodd"
					d="M0 6H-2C-2.55228 6 -3 6.44772 -3 7V9C-3 9.55228 -2.55228 10 -2 10H0C0.552285 10 1 9.55228 1 9V7C1 6.44772 0.552285 6 0 6ZM-2 4C-3.65685 4 -5 5.34315 -5 7V9C-5 10.6569 -3.65685 12 -2 12H0C1.65685 12 3 10.6569 3 9V7C3 5.34315 1.65685 4 0 4H-2Z"
					fill="black"
					fill-opacity="0.5"
				/>
				<path
					fillRule="evenodd"
					clipRule="evenodd"
					d="M9 6H7C6.44772 6 6 6.44772 6 7V9C6 9.55228 6.44772 10 7 10H9C9.55228 10 10 9.55228 10 9V7C10 6.44772 9.55228 6 9 6ZM7 4C5.34315 4 4 5.34315 4 7V9C4 10.6569 5.34315 12 7 12H9C10.6569 12 12 10.6569 12 9V7C12 5.34315 10.6569 4 9 4H7Z"
					fill="black"
				/>
				<path
					fillRule="evenodd"
					clipRule="evenodd"
					d="M18 6H16C15.4477 6 15 6.44772 15 7V9C15 9.55228 15.4477 10 16 10H18C18.5523 10 19 9.55228 19 9V7C19 6.44772 18.5523 6 18 6ZM16 4C14.3431 4 13 5.34315 13 7V9C13 10.6569 14.3431 12 16 12H18C19.6569 12 21 10.6569 21 9V7C21 5.34315 19.6569 4 18 4H16Z"
					fill="black"
					fill-opacity="0.5"
				/>
			</g>
			<defs>
				<clipPath id="clip0_1509_119">
					<rect
						width="16"
						height="16"
						fill="white"
						transform="matrix(-1 0 0 1 16 0)"
					/>
				</clipPath>
			</defs>
		</svg>
	);
};
